- data
A data.frame or extension (e.g. a tibble) containing values for
predictors and response variables.
- response
A data variable which must be a factor, integer or character
vector representing the prediction outcome on each observation
(Gold Standard).
If the variable presents more than two possible outcomes, classes or
categories:
New combined category represents the "absence" of the condition to predict.
See .condition for more information.
- predictor
A data variable which must be numeric, representing values
of a classifier or predictor for each observation.
- lower_fpr, upper_fpr
Two numbers between 0 and 1, inclusive. These
numbers represent lower and upper values of FPR region where to calculate
partial area under curve.
- .condition
A value from response that represents class, category or
condition of interest which wants to be predicted.
If NULL, condition of interest will be selected automatically depending on
response type.
Once the class of interest is selected, rest of them will be collapsed in a
common category, representing the "absence" of the condition to be predicted.
See vignette("selecting-condition") for further information on how
automatic selection is performed and details on selecting the condition of
interest.
- .invalid
If FALSE, the default, sp_auc() will return NA when
ROC curve does not fit theoretical bounds and index cannot be applied.
If TRUE, function will force the calculation and return a value despite
probably being incorrect.