This dataset contains gene expression levels obtained from healthy and diseased tissue samples from patients with prostate cancer. The data includes the expression values for each selected gene, as well as clinical variables derived from the direct observation of the tissue samples.
Format
A tibble with 554 observations and 2654 variables:
- ENSG...
Gene expression levels. Column names correspond to the measured gene identifier.
- gleason_score
Score derived from tissue observation, which indicates disease severity and progression.
- disease
Categorical variable indicating whether the sample comes from diseased ("1") or healthy ("0") tissue.
- prognostic
Categorical variable indicating whether a poor ("1") or a good ("0") prognosis is expected for the patient. Diseased cases in the dataset are assumed to have a poor prognosis when their Gleason score is equal to or above 8. Non-diseased cases are labelled as "Normal".
Raw data obtained from The Cancer Genome Atlas (TCGA) through the Genomic Data Commons Data Portal (https://portal.gdc.cancer.gov/). Data have been preprocessed and curated by the authors (e.g., gene selection and variable creation, etc.) to create the final dataset.
The data shown here are in whole or part based upon data generated by the TCGA Research Network: https://www.cancer.gov/tcga.