Calculate a series of metrics describing global and local performance for selected classifiers in a dataset.
summarize_dataset(
data,
predictors = NULL,
response,
ratio,
threshold,
.condition = NULL,
.progress = FALSE
)A list with different elements:
Performance metrics for each of evaluated classifiers.
Overall description of performance metrics in the dataset.
A data.frame or extension (e.g. a tibble) containing values for predictors and response variables.
A vector of numeric data variables which represents the different classifiers or predictors in data to be summarized.
If NULLand by default, predictors will match all numeric variables in
data with the exception of response, given that it has a numeric type.
A data variable which must be a factor, integer or character vector representing the prediction outcome on each observation (Gold Standard).
If the variable presents more than two possible outcomes, classes or categories:
The outcome of interest (the one to be predicted) will remain distinct.
All other categories will be combined into a single category.
New combined category represents the "absence" of the condition to predict.
See .condition for more information.
Ratio or axis where to apply calculations.
If "tpr", only points within the specified region of TPR, y axis, will be
considered for calculations.
If "fpr", only points within the specified region of FPR, x axis, will be
considered for calculations.
A number between 0 and 1, both inclusive, which represents the region bound where to calculate partial area under curve.
If ratio = "tpr", it represents lower bound of the TPR region, being its
upper limit equal to 1.
If ratio = "fpr", it represents the upper bound of the FPR region,
being its lower limit equal to 0.
A value from response that represents class, category or condition of interest which wants to be predicted.
If NULL, condition of interest will be selected automatically depending on
response type.
Once the class of interest is selected, rest of them will be collapsed in a common category, representing the "absence" of the condition to be predicted.
See vignette("selecting-condition") for further information on how
automatic selection is performed and details on selecting the condition of
interest.
If TRUE, show progress of calculations.
summarize_dataset(iris, response = Species, ratio = "tpr", threshold = 0.9)
Run the code above in your browser using DataLab